==> pgpoolAdmin-2.0.0-beta1.tar.gz: pgpoolAdmin-2.0.0-beta1/install/lang/en.lang.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in English
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Ryuma Ando <ando@ecomas.co.jp>
 * @copyright  2003-2007		PgPool Global Development Group
 * @version    CVS: $Id: en.lang.php,v 1.3 2007/06/28 12:51:37 y-asaba Exp $
 */

$message = array(
    'lang' => 'en',
    'strLang' => 'English',
    'strNext' => 'Next',
    'strCheck' => 'Check',
    'strDirectoryCheck' => 'Directory Check',
    'strParameterCheck' => 'Parameter Setting',
    'strFinish' => 'Finish',
    'strPgConfFile' => 'pgpool.conf File',
    'strPasswordFile' => 'Password file',
    'strPgmgtFile' => 'pgpoolAdmin Setting File',
    'strTempDir' => 'Template Directory',
    'strPgpoolCommand' => 'Pgpool Command',
    'strPgpoolCommandOption' => 'Pgpool Command Option',
    'strCmdC' => 'Clears query cache',
    'strCmdD' => 'debug mode',
    'strCmdM' => 'stop mode',
    'strCmdN' => 'don\'t run in daemon mode',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => 'If it is a blank, this option is ignored.',
    'strPgpoolLogFile' => 'Pgpool Logfile',
    'strPcpDir' => 'PCP directory',
    'strPcpTimeout' => 'PCP Timeout',
    'strPcpHostName' => 'PCP Hostname',
    'strPcpRefreshTime' => 'Refresh Time',
    'msgCongratulations' => 'Congratulations. Pgpool Administration Tool was installed!',
    'msgDeleteInstallDir' => ' : Please remove this directory',
    'msgToTop' => 'top'
);

?>

==> pgpoolAdmin-2.2-beta1.tar.gz: pgpoolAdmin-2.2-beta1/install/lang/en.lang.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in English
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Ryuma Ando <ando@ecomas.co.jp>
 * @copyright  2003-2008		PgPool Global Development Group
 * @version    CVS: $Id: en.lang.php,v 1.6 2008/02/01 08:57:41 yamaguti Exp $
 */

$message = array(
    'lang' => 'en',
    'strLang' => 'English',
    'strNext' => 'Next',
    'strCheck' => 'Check',
    'strDirectoryCheck' => 'Directory Check',
    'strParameterCheck' => 'Parameter Setting',
    'strFinish' => 'Finish',
    'strPgConfFile' => 'pgpool.conf File',
    'strPasswordFile' => 'pcp.conf File',
    'strPgmgtFile' => 'pgpoolAdmin Setting File',
    'strTempDir' => 'Template Directory',
    'strPgpoolCommand' => 'pgpool Command',
    'strPgpoolCommandOption' => 'pgpool Command Option',
    'strCmdC' => 'Clears query cache',
    'strCmdD' => 'debug mode',
    'strCmdM' => 'stop mode',
    'strCmdN' => 'don\'t run in daemon mode',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => 'If it is a blank, this option is ignored.',
    'strPgpoolLogFile' => 'pgpool Logfile',
    'strPcpDir' => 'PCP directory',
    'strPcpTimeout' => 'PCP Timeout',
    'strPcpHostName' => 'PCP Hostname',
    'strPcpRefreshTime' => 'Refresh Time',
    'msgCongratulations' => 'Congratulations. pgpool Administration Tool was installed!',
    'msgDeleteInstallDir' => ' : Please remove this directory',
    'msgToTop' => 'top'
);

?>
